@@ -310,12 +310,35 @@ None by default.
 
 =head1 ACKNOWLEDGEMENTS
 
-Stephen Morgan for creating the TT template and SVG.
+Thanks to Foxtons for letting us put this on CPAN, Todd Caine for heads up on
+reparsing the template (but not using atm), David Meibusch for TimeSeries and a
+load of other ideas, Stephen Morgan for creating the TT template and SVG, and
+thanks for all the patches by Andrew Ruthven and others.
 
 =head1 AUTHOR
 
 Leo Lapworth (LLAP@cuckoo.org)
 
+=head1 MAINTAINER
+
+Florent Angly <florent.angly@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2003, Leo Lapworth 
+
+This module is free software; you can redistribute it or 
+modify it under the same terms as Perl itself.
+
+=head1 BUGS
+
+Please report any bugs or feature requests to bug-graph-svg-tt@rt.cpan.org, or
+through the web interface at http://rt.cpan.org.
+
+The Graph::SVG::TT development repository is located on GitHub at
+L<http://github.com/ranguard/svg-tt-graph>. Get the latest development version
+using: git clone git://github.com/ranguard/svg-tt-graph.git
+
 =head1 SEE ALSO
 
 L<SVG::TT::Graph>,
@@ -547,8 +570,10 @@ __DATA__
     [% IF dataset.data.$field != '' %]
       [% max_y_value = max_y_value + dataset.data.$field %]
     [% END %]
-    [% IF max_key_size < dataset.title.length %]
-      [% max_key_size = dataset.title.length %]
+    [% IF dataset.title %]
+      [% IF max_key_size < dataset.title.length %]
+        [% max_key_size = dataset.title.length %]
+      [% END %]
     [% END %]
   [% END %]
 
@@ -617,7 +642,7 @@ __DATA__
   <!-- setting highest value to be max_value as no max_scale_value defined -->
   [% max_scale_value = max_value %]
 [% END %]
-	
+
 <!-- base line -->
 [% base_line = h + y %]
 
