@@ -297,11 +297,34 @@ None by default.
 
 =head1 ACKNOWLEDGEMENTS
 
-Stephen Morgan for creating the TT template and SVG.
+Thanks to Foxtons for letting us put this on CPAN, Todd Caine for heads up on
+reparsing the template (but not using atm), David Meibusch for TimeSeries and a
+load of other ideas, Stephen Morgan for creating the TT template and SVG, and
+thanks for all the patches by Andrew Ruthven and others.
 
 =head1 AUTHOR
 
-Leo Lapworth (LLAP@cuckoo.org)
+Leo Lapworth <LLAP@cuckoo.org>
+
+=head1 MAINTAINER
+
+Florent Angly <florent.angly@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2003, Leo Lapworth 
+
+This module is free software; you can redistribute it or 
+modify it under the same terms as Perl itself.
+
+=head1 BUGS
+
+Please report any bugs or feature requests to bug-graph-svg-tt@rt.cpan.org, or
+through the web interface at http://rt.cpan.org.
+
+The Graph::SVG::TT development repository is located on GitHub at
+L<http://github.com/ranguard/svg-tt-graph>. Get the latest development version
+using: git clone git://github.com/ranguard/svg-tt-graph.git
 
 =head1 SEE ALSO
 
@@ -580,7 +603,7 @@ __DATA__
 
 [% max_key_size = 0 %]  
 [% FOREACH y_label = config.fields %]
-   <!-- find largest dataset title for Key size -->
+  <!-- find largest dataset title for Key size -->
   [% IF max_key_size < data.0.title.length %]
     [% max_key_size = data.0.title.length %]
   [% END %]
